/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2006 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id: $
 * -------------------------------------------------------------------------
 */
package org.objectweb.petals.component.common.listener;

import java.util.concurrent.ThreadPoolExecutor;

/**
 * This class contains the all configuration parameters needed by the
 * ThreaPoolExecutor and its associated queue used by the
 * MessageExchangeListener to process messages.
 * 
 * @version $Revision: $ $Date: $
 * @since Petals 1.2
 * @author cdeneux (Capgemini Sud)
 */
public class ThreadPoolConfiguration {

    /**
     * The size of the thread pool queue.
     */
    private int queueSize = 50;

    /**
     * The number of threads to keep in the pool, even if they are idle.
     * 
     * @see ThreadPoolExecutor
     */
    private int corePoolSize = 10;

    /**
     * The maximum number of threads to allow in the pool.
     * 
     * @see ThreadPoolExecutor
     */
    private int maxPoolSize = 50;

    /**
     * When the number of threads is greater than the core, this is the maximum
     * time (in seconds) that excess idle threads will wait for new tasks before
     * terminating.
     * 
     * @see ThreadPoolExecutor
     */
    private long keepAliveTime = 600;

    public int getCorePoolSize() {
        return corePoolSize;
    }

    public void setCorePoolSize(int corePoolSize) {
        this.corePoolSize = corePoolSize;
    }

    public long getKeepAliveTime() {
        return keepAliveTime;
    }

    public void setKeepAliveTime(long keepAliveTime) {
        this.keepAliveTime = keepAliveTime;
    }

    public int getMaxPoolSize() {
        return maxPoolSize;
    }

    public void setMaxPoolSize(int maxPoolSize) {
        this.maxPoolSize = maxPoolSize;
    }

    public int getQueueSize() {
        return queueSize;
    }

    public void setQueueSize(int queueSize) {
        this.queueSize = queueSize;
    }
}
